from wtforms.validators import ValidationError
from datetime import date


def date_check(form, field):
    """
    Checks that the date of the pitstop is not before the date of the latest pitstop and not after today.

    :param form: the form where the field is in
    :param field: the field to check
    :return: Nothing or a ValidationError if the limits are not kept
    """
    if field.data < form.last_pitstop.date:
        raise ValidationError('The new date must not be before %s' % form.last_pitstop.date)
    if field.data > date.today():
        raise ValidationError('The new date must not be after %s' % date.today())


def odometer_check(form, field):
    """

    :param form:
    :param field:
    :return:
    """
    if not form.same_odometer_allowed and field.data <= form.last_pitstop.odometer:
        raise ValidationError('The new odometer value must be higher than %i km' % form.last_pitstop.odometer)
    if form.same_odometer_allowed and field.data < form.last_pitstop.odometer:
        raise ValidationError('The new odometer value must be higher than %i km' % form.last_pitstop.odometer)


def litres_check(form, field):
    if field.data is not None and field.data <= 0:
        raise ValidationError('You must fuel at least 0.1 l')


def costs_check(form, field):
    if field.data is not None and field.data <= 0:
        raise ValidationError('Costs must be above 0.01 €.')


def edit_costs_check(form, field):
    """
    Costs must be given, if a default value was given to the form field.
    :param form:
    :param field:
    :return:
    """
    costs_check_required = (form.costs.default is not None and form.costs.default > 0)
    if costs_check_required and field.data is not None and field.data <= 0:
        raise ValidationError('Costs must be above 0.01 €.')


